summaryrefslogtreecommitdiffstats
path: root/Source/cmConfigureFileCommand.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'Source/cmConfigureFileCommand.cxx')
-rw-r--r--Source/cmConfigureFileCommand.cxx22
1 files changed, 13 insertions, 9 deletions
diff --git a/Source/cmConfigureFileCommand.cxx b/Source/cmConfigureFileCommand.cxx
index 2a8d3a4..f2ce3da 100644
--- a/Source/cmConfigureFileCommand.cxx
+++ b/Source/cmConfigureFileCommand.cxx
@@ -42,15 +42,19 @@ bool cmConfigureFileCommand
// for CMake 2.0 and earlier CONFIGURE_FILE defaults to the FinalPass,
- // after 2.0 it only does InitialPass
- this->Immediate = false;
- const char* versionValue
- = this->Makefile->GetDefinition("CMAKE_BACKWARDS_COMPATIBILITY");
- if (versionValue && atof(versionValue) > 2.0)
- {
- this->Immediate = true;
- }
-
+ // after 2.0 it only does InitialPass, this is policy CMP_0003
+ switch (this->Makefile->GetPolicyStatus(cmPolicies::CMP_0003))
+ {
+ case cmPolicies::WARN:
+ cmSystemTools::Message(
+ this->Makefile->GetPolicies()->GetPolicyWarning
+ (cmPolicies::CMP_0003).c_str(),"Warning");
+ case cmPolicies::OLD:
+ this->Immediate = false;
+ break;
+ default:
+ this->Immediate = true;
+ }
this->AtOnly = false;
for(unsigned int i=2;i < args.size();++i)